==> cdk8s-mongo-sts-0.0.7.tar.gz: cdk8s-mongo-sts-0.0.7/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk8s-mongo-sts",
    "version": "0.0.7",
    "description": "cdk8s-mongo-sts",
    "license": "Apache-2.0",
    "url": "https://github.com/Hunter-Thompson/cdk8s-mongo-sts",
    "long_description_content_type": "text/markdown",
    "author": "Hunter Thompson<aatman@auroville.org.in>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/Hunter-Thompson/cdk8s-mongo-sts"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk8s_mongo_sts",
        "cdk8s_mongo_sts._jsii"
    ],
    "package_data": {
        "cdk8s_mongo_sts._jsii": [
            "cdk8s-mongo-sts@0.0.7.jsii.tgz"
        ],
        "cdk8s_mongo_sts": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "cdk8s-plus-17>=1.0.0.b8, <2.0.0",
        "cdk8s>=1.0.0.b8, <2.0.0",
        "constructs==3.3.5",
        "jsii>=1.20.1, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk8s-mongo-sts-0.0.9.tar.gz: cdk8s-mongo-sts-0.0.9/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk8s-mongo-sts",
    "version": "0.0.9",
    "description": "@opencdk8s/cdk8s-mongo-sts",
    "license": "Apache-2.0",
    "url": "https://github.com/opencdk8s/cdk8s-mongo-sts",
    "long_description_content_type": "text/markdown",
    "author": "Hunter Thompson<aatman@auroville.org.in>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/opencdk8s/cdk8s-mongo-sts"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk8s_mongo_sts",
        "cdk8s_mongo_sts._jsii"
    ],
    "package_data": {
        "cdk8s_mongo_sts._jsii": [
            "cdk8s-mongo-sts@0.0.9.jsii.tgz"
        ],
        "cdk8s_mongo_sts": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "cdk8s-plus-17>=1.0.0.b8, <2.0.0",
        "cdk8s>=1.0.0.b8, <2.0.0",
        "constructs>=3.3.5, <4.0.0",
        "jsii>=1.20.1, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
